==> v1.4.0.zip: user_saml/l10n/gl.js <==
OC.L10N.register(
    "user_saml",
    {
    "Saved" : "Gardado",
    "X.509 certificate of the Service Provider" : "Certificado X.509 do provedor do servizo",
    "Private key of the Service Provider" : "Chave privada do provedor do servizo",
    "Indicates that the nameID of the <samlp:logoutRequest> sent by this SP will be encrypted." : "Indica que o nameID do <samlp:logoutRequest> enviado por este SP vai ser cifrado.",
    "Indicates whether the <samlp:AuthnRequest> messages sent by this SP will be signed. [Metadata of the SP will offer this info]" : "Indica se as mensaxes <samlp:AuthnRequest> enviadas por este SP van ser asinadas. [Os metadatos do SP ofrecerán esta información]",
    "Indicates whether the  <samlp:logoutRequest> messages sent by this SP will be signed." : "Indica se as mensaxes <samlp:logoutRequest> enviadas por este SP van ser asinadas.",
    "Indicates whether the  <samlp:logoutResponse> messages sent by this SP will be signed." : "Indica se as mensaxes <samlp:logoutResponse> enviadas por este SP van ser asinadas.",
    "Whether the metadata should be signed." : "Se os metadatos deben ser asinados.",
    "Indicates a requirement for the <samlp:Response>, <samlp:LogoutRequest> and <samlp:LogoutResponse> elements received by this SP to be signed." : "Indica un requisito para os elementos <samlp:Response>, <samlp:LogoutRequest> e <samlp:LogoutResponse> recibidos por este SP para seren asinados.",
    "Indicates a requirement for the <saml:Assertion> elements received by this SP to be signed. [Metadata of the SP will offer this info]" : "Indica un requisito para os elementos <saml:Assertion> recibidos por este SP para seren asinados. [Os metadatos do SP ofrecerán esta información]",
    "Indicates a requirement for the <saml:Assertion> elements received by this SP to be encrypted." : "Indica un requisito para os elementos <saml:Assertion> recibidos por este SP para seren cifrados.",
    " Indicates a requirement for the NameID element on the SAMLResponse received by this SP to be present." : "Indica un requisito para que o elemento NameID no SAMLResponse recibido por este SP estea presente.",
    "Indicates a requirement for the NameID received by this SP to be encrypted." : "Indica un requisito para que o NameID recibido por este SP estea cifrado.",
    "Indicates if the SP will validate all received XML." : "Indica se o SP validará todos os XMLs recibidos.",
    "ADFS URL-Encodes SAML data as lowercase, and the toolkit by default uses uppercase. Enable for ADFS compatibility on signature verification." : "ADFS URL-Cifra datos SAML en minúsculas, e o conxunto de ferramentas usa maiúsculas como predeterminado. Active ADFS para a compatibilidade na sinatura de verificación.",
    "Attribute to map the UID to." : "Atributo para asignar ao UID.",
    "Only allow authentication if an account exists on some other backend. (e.g. LDAP)" : "Permitir soamente se existe unha conta noutro sistema. (p. ex. LDAP)",
    "Attribute to map the displayname to." : "Atributo ao que asignar o nome a amosar.",
    "Attribute to map the email address to." : "Atributo ao que asignar o enderezo de correo.",
    "Use SAML auth for the %s desktop clients (requires user re-authentication)" : "Usar autenticación SAML para os clientes de escritorio %s (necesita unha re-autenticación do usuario)",
    "SSO & SAML authentication" : "Autenticación SSO e SAML",
    "Open documentation" : "Abrir a documentación",
    "Please choose whether you want to authenticate using the SAML provider built-in in Nextcloud or whether you want to authenticate against an environment variable." : "Por favor escolla se quere autenticarse usando o provedor SAML integrado en Nextcloud ou se quere autenticarse cunha variábel de entorno.",
    "Use built-in SAML authentication" : "Usar a autenticación integrada de SAML",
    "Use environment variable" : "Usar variábel de entorno",
    "Make sure to configure an administrative user that can access the instance via SSO. Logging-in with your regular %s account won't be possible anymore." : "Asegúrese de configurar un usuario administrativo que poida acceder á instancia a través de SSO. Acceder coa sua conta normal %s xa non será posíbel.",
    "General" : "Xeral",
    "Service Provider Data" : "Datos do provedor do servizo",
    "If your Service Provider should use certificates you can optionally specify them here." : "Se o seu provedor do servizo usa certificados pode, opcionalmente, especificalos aquí.",
    "Show Service Provider settings…" : "Amosar os axustes do Proveedor dos Servizos...",
    "Identity Provider Data" : "Datos do Provedor de Identidade",
    "Configure your IdP settings here." : "Configure os axustes do seu IdP aquí.",
    "Identifier of the IdP entity (must be a URI)" : "Identificador da entidade IdP (ten que ser unha URI)",
    "URL Target of the IdP where the SP will send the Authentication Request Message" : "URL obxectivo do IdP onde o SP enviará a Mensaxe de Solicitude de Autenticación",
    "Show optional Identity Provider settings…" : "Amosar axustes opcionais do Provedor de Identidade...",
    "URL Location of the IdP where the SP will send the SLO Request" : "Enderezo URL do IdP onde o SP enviará as solicitudes SLO",
    "Public X.509 certificate of the IdP" : "Certificado público X.509 do IdP",
    "Attribute mapping" : "Asignación de atributos",
    "Show attribute mapping settings…" : "Amosar axustes de asignación de atributos...",
    "Security settings" : "Axustes de seguridade",
    "For increased security we recommend enabling the following settings if supported by your environment." : "Para incrementar a seguridade recomendámoslle que active os seguintes axustes se son admitidos polo seu entorno.",
    "Show security settings…" : "Amosar axustes de seguridade...",
    "Signatures and encryption offered" : "Sinaturas e cifrado ofrecidos",
    "Signatures and encryption required" : "Sinaturas e cifrado requiridos",
    "Download metadata XML" : "Descargar metadatos XML",
    "Metadata invalid" : "Metadatos incorrectos",
    "Metadata valid" : "Metadatos correctos",
    "Account not provisioned." : "Conta non suministrada.",
    "Your account is not provisioned, access to this service is thus not possible." : "A súa conta non está aprovisionada, polo que non é posíbel o acceso a este servizo.",
    "Indicates if the SP will validate all received XMLs." : "Indica se o SP validará todos os XML recibidos.",
    "Only allow authentication if an account is existent on some other backend. (e.g. LDAP)" : "Permitir a autenticación só se a conta existe nalgunha outra infraestrutura. (p. ex. LDAP)",
    "Show Service Provider settings ..." : "Amosar os axustes do Provedor do Servizo ...",
    "Show optional Identity Provider settings ..." : "Amosar axustes opcionais do Provedor da Identidade ...",
    "Show security settings ..." : "Amosar axustes de seguridade ...",
    "If you want to optionally map SAML attributes to the user you can configure these here." : "Se, opcionalmente, quere asignar atributos SAML ao usuario, pode configuralos aquí.",
    "Show attribute mapping settings ..." : "Amosar os axustes de asignación de atributos ..."
},
"nplurals=2; plural=(n != 1);");

==> v1.6.1.zip: user_saml/l10n/gl.js <==
OC.L10N.register(
    "user_saml",
    {
    "Saved" : "Gardado",
    "X.509 certificate of the Service Provider" : "Certificado X.509 do provedor do servizo",
    "Private key of the Service Provider" : "Chave privada do provedor do servizo",
    "Indicates that the nameID of the <samlp:logoutRequest> sent by this SP will be encrypted." : "Indica que o nameID do <samlp:logoutRequest> enviado por este SP vai ser cifrado.",
    "Indicates whether the <samlp:AuthnRequest> messages sent by this SP will be signed. [Metadata of the SP will offer this info]" : "Indica se as mensaxes <samlp:AuthnRequest> enviadas por este SP van ser asinadas. [Os metadatos do SP ofrecerán esta información]",
    "Indicates whether the  <samlp:logoutRequest> messages sent by this SP will be signed." : "Indica se as mensaxes <samlp:logoutRequest> enviadas por este SP van ser asinadas.",
    "Indicates whether the  <samlp:logoutResponse> messages sent by this SP will be signed." : "Indica se as mensaxes <samlp:logoutResponse> enviadas por este SP van ser asinadas.",
    "Whether the metadata should be signed." : "Se os metadatos deben ser asinados.",
    "Indicates a requirement for the <samlp:Response>, <samlp:LogoutRequest> and <samlp:LogoutResponse> elements received by this SP to be signed." : "Indica un requisito para os elementos <samlp:Response>, <samlp:LogoutRequest> e <samlp:LogoutResponse> recibidos por este SP para seren asinados.",
    "Indicates a requirement for the <saml:Assertion> elements received by this SP to be signed. [Metadata of the SP will offer this info]" : "Indica un requisito para os elementos <saml:Assertion> recibidos por este SP para seren asinados. [Os metadatos do SP ofrecerán esta información]",
    "Indicates a requirement for the <saml:Assertion> elements received by this SP to be encrypted." : "Indica un requisito para os elementos <saml:Assertion> recibidos por este SP para seren cifrados.",
    " Indicates a requirement for the NameID element on the SAMLResponse received by this SP to be present." : "Indica un requisito para que o elemento NameID no SAMLResponse recibido por este SP estea presente.",
    "Indicates a requirement for the NameID received by this SP to be encrypted." : "Indica un requisito para que o NameID recibido por este SP estea cifrado.",
    "Indicates if the SP will validate all received XML." : "Indica se o SP validará todos os XMLs recibidos.",
    "ADFS URL-Encodes SAML data as lowercase, and the toolkit by default uses uppercase. Enable for ADFS compatibility on signature verification." : "ADFS URL-Cifra datos SAML en minúsculas, e o conxunto de ferramentas usa maiúsculas como predeterminado. Active ADFS para a compatibilidade na sinatura de verificación.",
    "Attribute to map the UID to." : "Atributo para asignar ao UID.",
    "Only allow authentication if an account exists on some other backend. (e.g. LDAP)" : "Permitir soamente se existe unha conta noutro sistema. (p. ex. LDAP)",
    "Attribute to map the displayname to." : "Atributo ao que asignar o nome a amosar.",
    "Attribute to map the email address to." : "Atributo ao que asignar o enderezo de correo.",
    "Use SAML auth for the %s desktop clients (requires user re-authentication)" : "Usar autenticación SAML para os clientes de escritorio %s (necesita unha re-autenticación do usuario)",
    "SSO & SAML authentication" : "Autenticación SSO e SAML",
    "Open documentation" : "Abrir a documentación",
    "Please choose whether you want to authenticate using the SAML provider built-in in Nextcloud or whether you want to authenticate against an environment variable." : "Por favor escolla se quere autenticarse usando o provedor SAML integrado en Nextcloud ou se quere autenticarse cunha variábel de entorno.",
    "Use built-in SAML authentication" : "Usar a autenticación integrada de SAML",
    "Use environment variable" : "Usar variábel de entorno",
    "General" : "Xeral",
    "Service Provider Data" : "Datos do provedor do servizo",
    "If your Service Provider should use certificates you can optionally specify them here." : "Se o seu provedor do servizo usa certificados pode, opcionalmente, especificalos aquí.",
    "Show Service Provider settings…" : "Amosar os axustes do Proveedor dos Servizos...",
    "Identity Provider Data" : "Datos do Provedor de Identidade",
    "Configure your IdP settings here." : "Configure os axustes do seu IdP aquí.",
    "Identifier of the IdP entity (must be a URI)" : "Identificador da entidade IdP (ten que ser unha URI)",
    "URL Target of the IdP where the SP will send the Authentication Request Message" : "URL obxectivo do IdP onde o SP enviará a Mensaxe de Solicitude de Autenticación",
    "Show optional Identity Provider settings…" : "Amosar axustes opcionais do Provedor de Identidade...",
    "URL Location of the IdP where the SP will send the SLO Request" : "Enderezo URL do IdP onde o SP enviará as solicitudes SLO",
    "Public X.509 certificate of the IdP" : "Certificado público X.509 do IdP",
    "Attribute mapping" : "Asignación de atributos",
    "If you want to optionally map attributes to the user you can configure these here." : "Se queres asignar atributos opcionais ao usuario, podes configuralos aquí.",
    "Show attribute mapping settings…" : "Amosar axustes de asignación de atributos...",
    "Security settings" : "Axustes de seguridade",
    "For increased security we recommend enabling the following settings if supported by your environment." : "Para incrementar a seguridade recomendámoslle que active os seguintes axustes se son admitidos polo seu entorno.",
    "Show security settings…" : "Amosar axustes de seguridade...",
    "Signatures and encryption offered" : "Sinaturas e cifrado ofrecidos",
    "Signatures and encryption required" : "Sinaturas e cifrado requiridos",
    "Download metadata XML" : "Descargar metadatos XML",
    "Metadata invalid" : "Metadatos incorrectos",
    "Metadata valid" : "Metadatos correctos",
    "Account not provisioned." : "Conta non suministrada.",
    "Your account is not provisioned, access to this service is thus not possible." : "A súa conta non está aprovisionada, polo que non é posíbel o acceso a este servizo.",
    "Indicates if the SP will validate all received XMLs." : "Indica se o SP validará todos os XML recibidos.",
    "Only allow authentication if an account is existent on some other backend. (e.g. LDAP)" : "Permitir a autenticación só se a conta existe nalgunha outra infraestrutura. (p. ex. LDAP)",
    "Make sure to configure an administrative user that can access the instance via SSO. Logging-in with your regular %s account won't be possible anymore." : "Asegúrese de configurar un usuario administrativo que poida acceder á instancia a través de SSO. Acceder coa sua conta normal %s xa non será posíbel.",
    "Show Service Provider settings ..." : "Amosar os axustes do Provedor do Servizo ...",
    "Show optional Identity Provider settings ..." : "Amosar axustes opcionais do Provedor da Identidade ...",
    "If you want to optionally map SAML attributes to the user you can configure these here." : "Se, opcionalmente, quere asignar atributos SAML ao usuario, pode configuralos aquí.",
    "Show attribute mapping settings ..." : "Amosar os axustes de asignación de atributos ...",
    "Show security settings ..." : "Amosar axustes de seguridade ..."
},
"nplurals=2; plural=(n != 1);");
